@@ -18,7 +18,6 @@ module.exports = {
     '../../.eslintrc.js',
   ],
   plugins: [
-    'import',
     'no-relative-import-paths',
     'simple-import-sort',
   ],
@@ -36,9 +35,6 @@ module.exports = {
 
     'simple-import-sort/imports': 'error',
     'simple-import-sort/exports': 'error',
-    "import/first": "error",
-    "import/newline-after-import": "error",
-    "import/no-duplicates": "error",
 
     "no-relative-import-paths/no-relative-import-paths": [
       "error",
