@@ -12,7 +12,11 @@
 
 import { JSONSchema7 } from 'json-schema';
 
-import { devWorkspaceResourcesExample, dockerConfigExample } from '@/constants/examples';
+import {
+  dataResolverSchemaExample,
+  devWorkspaceResourcesExample,
+  dockerConfigExample,
+} from '@/constants/examples';
 
 export const authenticationHeaderSchema: JSONSchema7 = {
   type: 'object',
@@ -62,6 +66,19 @@ export const namespacedTemplateSchema: JSONSchema7 = {
   required: ['namespace', 'templateName'],
 };
 
+export const namespacedWorkspacePreferencesSchema: JSONSchema7 = {
+  type: 'object',
+  properties: {
+    namespace: {
+      type: 'string',
+    },
+    provider: {
+      type: 'string',
+    },
+  },
+  required: ['namespace', 'provider'],
+};
+
 export const namespacedSchema: JSONSchema7 = {
   type: 'object',
   properties: {
@@ -165,7 +182,7 @@ export const devfileVersionSchema: JSONSchema7 = {
   required: ['version'],
 };
 
-export const yamlResolverSchema: JSONSchema7 = {
+export const dataResolverSchema: JSONSchema7 = {
   type: 'object',
   properties: {
     url: {
@@ -174,6 +191,7 @@ export const yamlResolverSchema: JSONSchema7 = {
     },
   },
   required: ['url'],
+  examples: [dataResolverSchemaExample],
 };
 
 export const devWorkspaceResourcesSchema: JSONSchema7 = {
