@@ -12,6 +12,7 @@
 
 import {
   IDevWorkspaceApi,
+  IDevWorkspacePreferencesApi,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
   IEventApi,
@@ -68,4 +69,7 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
   get sshKeysApi(): IShhKeysApi {
     throw new Error('Method not implemented.');
   }
+  get devWorkspacePreferencesApi(): IDevWorkspacePreferencesApi {
+    throw new Error('Method not implemented.');
+  }
 }
