@@ -11,7 +11,8 @@
  */
 
 import * as k8s from '@kubernetes/client-node';
-import { retryableExec } from './retryableExec';
+
+import { retryableExec } from '@/devworkspaceClient/services/helpers/retryableExec';
 
 export type CoreV1API = Pick<
   k8s.CoreV1Api,
@@ -20,6 +21,8 @@ export type CoreV1API = Pick<
   | 'listNamespacedEvent'
   | 'listNamespacedPod'
   | 'listNamespacedSecret'
+  | 'patchNamespacedConfigMap'
+  | 'readNamespacedConfigMap'
   | 'readNamespacedPod'
   | 'readNamespacedSecret'
   | 'replaceNamespacedSecret'
@@ -40,6 +43,10 @@ export function prepareCoreV1API(kc: k8s.KubeConfig): CoreV1API {
       retryableExec(() => coreV1API.listNamespacedPod(...args)),
     listNamespacedSecret: (...args: Parameters<typeof coreV1API.listNamespacedSecret>) =>
       retryableExec(() => coreV1API.listNamespacedSecret(...args)),
+    patchNamespacedConfigMap: (...args: Parameters<typeof coreV1API.patchNamespacedConfigMap>) =>
+      retryableExec(() => coreV1API.patchNamespacedConfigMap(...args)),
+    readNamespacedConfigMap: (...args: Parameters<typeof coreV1API.readNamespacedConfigMap>) =>
+      retryableExec(() => coreV1API.readNamespacedConfigMap(...args)),
     readNamespacedPod: (...args: Parameters<typeof coreV1API.readNamespacedPod>) =>
       retryableExec(() => coreV1API.readNamespacedPod(...args)),
     readNamespacedSecret: (...args: Parameters<typeof coreV1API.readNamespacedSecret>) =>
