@@ -17,7 +17,8 @@ import * as mockClient from '@kubernetes/client-node';
 import { CoreV1Api, HttpError, V1Pod, V1Status } from '@kubernetes/client-node';
 import * as request from 'request';
 import { Writable } from 'stream';
-import { LogsApiService } from '../';
+
+import { LogsApiService } from '@/devworkspaceClient/services/logsApi';
 
 jest.mock('../const', () => ({
   RETRY_DELAY_SECONDS: 0.1,
@@ -42,10 +43,6 @@ jest.mock('@kubernetes/client-node', () => {
   };
 });
 
-// mute console.error
-console.warn = jest.fn();
-console.error = jest.fn();
-
 describe('Logs API Service', () => {
   let logsApiService: LogsApiService;
 
