@@ -10,9 +10,11 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { FastifyInstance } from 'fastify';
 import fastifySwagger from '@fastify/swagger';
 import fastifySwaggerUi from '@fastify/swagger-ui';
+import { FastifyInstance } from 'fastify';
+
+import { logger } from '@/utils/logger';
 
 const ROUTE_PREFIX = '/dashboard/api/swagger';
 
@@ -25,7 +27,7 @@ type MySchema = {
 };
 
 export function registerSwagger(server: FastifyInstance) {
-  console.log(`Che Dashboard swagger is running on "${ROUTE_PREFIX}".`);
+  logger.info(`Che Dashboard swagger is running on "${ROUTE_PREFIX}".`);
 
   server.register(fastifySwagger, {
     mode: 'dynamic',
@@ -61,6 +63,7 @@ export function registerSwagger(server: FastifyInstance) {
     uiConfig: {
       tryItOutEnabled: true,
       validatorUrl: null,
+      layout: 'BaseLayout',
     },
   });
 }
