@@ -11,7 +11,9 @@
  */
 
 import { existsSync, readFileSync } from 'fs';
-import { isLocalRun } from '../../../localRun';
+
+import { isLocalRun } from '@/localRun';
+import { logger } from '@/utils/logger';
 
 export const SERVICE_ACCOUNT_TOKEN_PATH = '/run/secrets/kubernetes.io/serviceaccount/token';
 
@@ -20,7 +22,7 @@ export function getServiceAccountToken(): string {
     return process.env.SERVICE_ACCOUNT_TOKEN as string;
   }
   if (!existsSync(SERVICE_ACCOUNT_TOKEN_PATH)) {
-    console.error('SERVICE_ACCOUNT_TOKEN is required');
+    logger.fatal('SERVICE_ACCOUNT_TOKEN is required');
     process.exit(1);
   }
   return readFileSync(SERVICE_ACCOUNT_TOKEN_PATH).toString();
