@@ -12,16 +12,17 @@
 
 import { api } from '@eclipse-che/common';
 import { FastifyInstance, FastifyReply, FastifyRequest } from 'fastify';
-import { baseApiPath } from '../../constants/config';
+
+import { baseApiPath } from '@/constants/config';
 import {
   namespacedSchema,
   personalAccessTokenBodySchema,
   personalAccessTokenParamsSchema,
-} from '../../constants/schemas';
-import { restParams } from '../../models';
-import { getSchema } from '../../services/helpers';
-import { getDevWorkspaceClient } from './helpers/getDevWorkspaceClient';
-import { getToken } from './helpers/getToken';
+} from '@/constants/schemas';
+import { restParams } from '@/models';
+import { getDevWorkspaceClient } from '@/routes/api/helpers/getDevWorkspaceClient';
+import { getToken } from '@/routes/api/helpers/getToken';
+import { getSchema } from '@/services/helpers';
 
 const tags = ['Personal Access Token'];
 
