@@ -10,11 +10,12 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { render, screen } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
 import React from 'react';
 import renderer from 'react-test-renderer';
-import { render, screen } from '@testing-library/react';
+
 import { ErrorBoundary, STORAGE_KEY_RELOAD_NUMBER } from '..';
-import userEvent from '@testing-library/user-event';
 
 class GoodComponent extends React.Component {
   render() {
@@ -37,8 +38,9 @@ export class NoResourceComponent extends React.Component {
 // mute the outputs
 console.error = jest.fn();
 
+const mockOnError = jest.fn();
 function wrapComponent(componentToWrap: React.ReactNode) {
-  return <ErrorBoundary>{componentToWrap}</ErrorBoundary>;
+  return <ErrorBoundary onError={mockOnError}>{componentToWrap}</ErrorBoundary>;
 }
 
 describe('Error boundary', () => {
@@ -66,6 +68,7 @@ describe('Error boundary', () => {
       const showDetailsAction = screen.getByRole('button', { name: 'View stack' });
       userEvent.click(showDetailsAction);
 
+      expect(mockOnError).not.toHaveBeenCalled();
       expect(screen.queryByText('in BadComponent', { exact: false })).toBeTruthy();
       expect(screen.queryByText('in ErrorBoundary', { exact: false })).toBeTruthy();
 
@@ -98,6 +101,7 @@ describe('Error boundary', () => {
       const errorBoundary = wrapComponent(<NoResourceComponent />);
       render(errorBoundary);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(
         screen.queryByText('The application has been likely updated on the server.', {
           exact: false,
@@ -111,6 +115,7 @@ describe('Error boundary', () => {
       const errorBoundary = wrapComponent(<NoResourceComponent />);
       render(errorBoundary);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(
         screen.queryByText('Refreshing a page to get newer resources in', { exact: false }),
       ).toBeTruthy();
@@ -127,6 +132,7 @@ describe('Error boundary', () => {
       const stopCountdownAction = screen.getByRole('button', { name: 'Stop countdown' });
       userEvent.click(stopCountdownAction);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(
         screen.queryByText('Refreshing a page to get newer resources in', { exact: false }),
       ).toBeFalsy();
@@ -148,6 +154,7 @@ describe('Error boundary', () => {
 
       jest.advanceTimersByTime(35000);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(window.location.reload).toHaveBeenCalled();
       expect(window.location.reload).toHaveBeenCalledTimes(1);
     });
@@ -161,6 +168,7 @@ describe('Error boundary', () => {
       userEvent.click(reloadNowAction);
       userEvent.click(reloadNowAction);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(window.location.reload).toHaveBeenCalled();
       expect(window.location.reload).toHaveBeenCalledTimes(3);
     });
@@ -185,6 +193,7 @@ describe('Error boundary', () => {
       window.dispatchEvent(new Event('beforeunload'));
       render(errorBoundary);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(
         screen.queryByText(
           'Contact an administrator if refreshing continues after the next load.',
@@ -225,6 +234,7 @@ describe('Error boundary', () => {
       window.dispatchEvent(new Event('beforeunload'));
       render(goodComponent);
 
+      expect(mockOnError).toHaveBeenCalledWith('Loading chunk 23 failed.');
       expect(sessionStorage.getItem(STORAGE_KEY_RELOAD_NUMBER)).toBeNull();
     });
   });
