@@ -17,20 +17,20 @@ import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
 import { Action, Store } from 'redux';
+
+import { MIN_STEP_DURATION_MS, TIMEOUT_TO_STOP_SEC } from '@/components/WorkspaceProgress/const';
+import { WorkspaceParams } from '@/Routes/routes';
+import getComponentRenderer, { screen } from '@/services/__mocks__/getComponentRenderer';
+import devfileApi from '@/services/devfileApi';
+import { getDefer } from '@/services/helpers/deferred';
+import { AlertItem } from '@/services/helpers/types';
+import { constructWorkspace } from '@/services/workspace-adapter';
+import { AppThunk } from '@/store';
+import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+import { ActionCreators } from '@/store/Workspaces';
+
 import CommonStepCheckRunningWorkspacesLimit, { State } from '..';
-import { WorkspaceParams } from '../../../../../Routes/routes';
-import getComponentRenderer, {
-  screen,
-} from '../../../../../services/__mocks__/getComponentRenderer';
-import devfileApi from '../../../../../services/devfileApi';
-import { getDefer } from '../../../../../services/helpers/deferred';
-import { AlertItem } from '../../../../../services/helpers/types';
-import { constructWorkspace } from '../../../../../services/workspace-adapter';
-import { AppThunk } from '../../../../../store';
-import { ActionCreators } from '../../../../../store/Workspaces';
-import { DevWorkspaceBuilder } from '../../../../../store/__mocks__/devWorkspaceBuilder';
-import { FakeStoreBuilder } from '../../../../../store/__mocks__/storeBuilder';
-import { MIN_STEP_DURATION_MS, TIMEOUT_TO_STOP_SEC } from '../../../const';
 
 jest.mock('../../../TimeLimit');
 
