@@ -14,20 +14,20 @@ import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
 import { Store } from 'redux';
-import CreatingStepInitialize from '..';
+
+import { MIN_STEP_DURATION_MS } from '@/components/WorkspaceProgress/const';
+import getComponentRenderer, { waitFor } from '@/services/__mocks__/getComponentRenderer';
 import {
   DEV_WORKSPACE_ATTR,
   ERROR_CODE_ATTR,
   FACTORY_URL_ATTR,
   POLICIES_CREATE_ATTR,
-} from '../../../../../services/helpers/factoryFlow/buildFactoryParams';
-import { AlertItem } from '../../../../../services/helpers/types';
-import getComponentRenderer, {
-  waitFor,
-} from '../../../../../services/__mocks__/getComponentRenderer';
-import { DevWorkspaceBuilder } from '../../../../../store/__mocks__/devWorkspaceBuilder';
-import { FakeStoreBuilder } from '../../../../../store/__mocks__/storeBuilder';
-import { MIN_STEP_DURATION_MS } from '../../../const';
+} from '@/services/helpers/factoryFlow/buildFactoryParams';
+import { AlertItem } from '@/services/helpers/types';
+import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+
+import CreatingStepInitialize from '..';
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
