@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import common from '@eclipse-che/common';
+import common, { ApplicationId } from '@eclipse-che/common';
 import { AlertVariant } from '@patternfly/react-core';
 import { isEqual } from 'lodash';
 import React from 'react';
@@ -32,8 +32,9 @@ import { WorkspaceParams } from '@/Routes/routes';
 import { isAvailableEndpoint } from '@/services/helpers/api-ping';
 import { findTargetWorkspace } from '@/services/helpers/factoryFlow/findTargetWorkspace';
 import { AlertItem, LoaderTab } from '@/services/helpers/types';
-import { Workspace } from '@/services/workspace-adapter';
+import { Workspace, WorkspaceAdapter } from '@/services/workspace-adapter';
 import { AppState } from '@/store';
+import { selectApplications } from '@/store/ClusterInfo/selectors';
 import * as WorkspaceStore from '@/store/Workspaces';
 import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
@@ -159,37 +160,69 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
 
   protected buildAlertItem(error: Error): AlertItem {
     const key = this.name;
+    const actionCallbacks = [
+      {
+        title: 'Restart',
+        callback: () => {
+          applyRestartDefaultLocation(this.props.history.location);
+          this.handleRestart(key, LoaderTab.Progress);
+        },
+      },
+      {
+        title: 'Restart with default devfile',
+        callback: () => {
+          applyRestartInSafeModeLocation(this.props.history.location);
+          this.handleRestart(key, LoaderTab.Progress);
+        },
+      },
+    ];
+
+    const isOpenshift = this.props.applications.length === 1;
+    if (isOpenshift) {
+      actionCallbacks.push({
+        title: 'Edit the DevWorkspace spec',
+        callback: () => {
+          this.openDevWorkspaceClusterConsole();
+        },
+      });
+    }
+
     return {
       key,
       title: 'Failed to open the workspace',
       variant: AlertVariant.danger,
       children: common.helpers.errors.getMessage(error),
-      actionCallbacks: [
-        {
-          title: 'Restart',
-          callback: () => {
-            applyRestartDefaultLocation(this.props.history.location);
-            this.handleRestart(key, LoaderTab.Progress);
-          },
-        },
-        {
-          title: 'Restart with default devfile',
-          callback: () => {
-            applyRestartInSafeModeLocation(this.props.history.location);
-            this.handleRestart(key, LoaderTab.Progress);
-          },
-        },
-      ],
+      actionCallbacks,
     };
   }
 
+  private openDevWorkspaceClusterConsole(): void {
+    const { applications } = this.props;
+    const workspace = this.findTargetWorkspace(this.props);
+
+    const clusterConsole = applications.find(app => app.id === ApplicationId.CLUSTER_CONSOLE);
+
+    if (!clusterConsole || !workspace) {
+      return;
+    }
+
+    const devWorkspaceConsoleUrl = WorkspaceAdapter.buildClusterConsoleUrl(
+      workspace.ref,
+      clusterConsole.url,
+    );
+
+    const target = 'devWorkspaceSpec' + workspace.uid;
+
+    window.open(`${devWorkspaceConsoleUrl}/yaml`, target);
+  }
+
   render(): React.ReactNode {
     const { distance, hasChildren } = this.props;
     const { name, lastError } = this.state;
 
     const isActive = distance === 0;
-    const isError = lastError !== undefined;
-    const isWarning = false;
+    const isError = false;
+    const isWarning = lastError !== undefined;
 
     return (
       <React.Fragment>
@@ -211,6 +244,7 @@ class StartingStepOpenWorkspace extends ProgressStep<Props, State> {
 
 const mapStateToProps = (state: AppState) => ({
   allWorkspaces: selectAllWorkspaces(state),
+  applications: selectApplications(state),
 });
 
 const connector = connect(mapStateToProps, WorkspaceStore.actionCreators, null, {
