@@ -18,6 +18,7 @@ import getDecorators from 'inversify-inject-decorators';
 import { AppAlerts } from '@/services/alerts/appAlerts';
 import { WebsocketClient } from '@/services/backend-client/websocketClient';
 import { IssuesReporterService } from '@/services/bootstrap/issuesReporter';
+import { WarningsReporterService } from '@/services/bootstrap/warningsReporter';
 import { WorkspaceStoppedDetector } from '@/services/bootstrap/workspaceStoppedDetector';
 import { DevWorkspaceClient } from '@/services/workspace-client/devworkspace/devWorkspaceClient';
 import { DevWorkspaceDefaultPluginsHandler } from '@/services/workspace-client/devworkspace/DevWorkspaceDefaultPluginsHandler';
@@ -31,5 +32,6 @@ container.bind(DevWorkspaceClient).toSelf().inSingletonScope();
 container.bind(AppAlerts).toSelf().inSingletonScope();
 container.bind(DevWorkspaceDefaultPluginsHandler).toSelf().inSingletonScope();
 container.bind(WorkspaceStoppedDetector).toSelf().inSingletonScope();
+container.bind(WarningsReporterService).toSelf().inSingletonScope();
 
 export { container, lazyInject };
