@@ -10,16 +10,16 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
 import {
-  Title,
   Button,
   EmptyState,
-  EmptyStateVariant,
-  EmptyStateIcon,
   EmptyStateBody,
+  EmptyStateIcon,
+  EmptyStateVariant,
+  Title,
 } from '@patternfly/react-core';
-import { RegistryIcon, PlusCircleIcon } from '@patternfly/react-icons';
+import { PlusCircleIcon, RegistryIcon } from '@patternfly/react-icons';
+import React from 'react';
 
 type Props = {
   onAddRegistry: () => void;
