@@ -12,10 +12,15 @@
 
 import React from 'react';
 
-import { Props, State } from '..';
+import { Props } from '@/pages/WorkspaceDetails/OverviewTab/StorageType';
 
-export default class StorageTypeFormGroup extends React.PureComponent<Props, State> {
+export default class StorageTypeFormGroup extends React.PureComponent<Props> {
   render() {
-    return <div>Fake Storage Type Form</div>;
+    return (
+      <div>
+        Mock Storage Type Form
+        <button onClick={() => this.props.onSave('per-workspace')}>Change storage type</button>
+      </div>
+    );
   }
 }
