@@ -21,13 +21,22 @@ import {
 import SessionStorageService, { SessionStorageKey } from '@/services/session-storage';
 
 const mockFetchData = jest.fn();
-jest.mock('../fetchData', () => {
+jest.mock('@/services/registry/fetchData', () => {
   return {
     fetchData: async (href: string) => {
       return mockFetchData(href);
     },
   };
 });
+
+const mockFetchRemoteData = jest.fn();
+jest.mock('@/services/backend-client/dataResolverApi', () => {
+  return {
+    getDataResolver: async (href: string) => {
+      return mockFetchRemoteData(href);
+    },
+  };
+});
 console.error = jest.fn();
 console.warn = jest.fn();
 
@@ -74,11 +83,15 @@ describe('fetch registry metadata', () => {
       mockSessionStorageServiceGet.mockReturnValue(undefined);
 
       mockFetchData.mockRejectedValueOnce(new Error('Unsupported index URL'));
-      mockFetchData.mockResolvedValueOnce([]);
+      mockFetchRemoteData.mockRejectedValueOnce(new Error('Unsupported index URL'));
+      mockFetchRemoteData.mockResolvedValueOnce([]);
 
       await fetchRegistryMetadata(baseUrl, true);
 
-      expect(mockFetchData.mock.calls).toEqual([
+      expect(mockFetchData).toBeCalledWith(
+        'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index',
+      );
+      expect(mockFetchRemoteData.mock.calls).toEqual([
         [`https://eclipse-che.github.io/che-devfile-registry/7.71.0/index`],
         [`https://eclipse-che.github.io/che-devfile-registry/7.71.0/devfiles/index.json`],
       ]);
@@ -94,7 +107,7 @@ describe('fetch registry metadata', () => {
         },
       };
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(undefined);
 
       const resolved = await fetchRegistryMetadata(baseUrl, true);
@@ -102,7 +115,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith(
+      expect(mockFetchRemoteData).toBeCalledWith(
         'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index',
       );
       expect(mockSessionStorageServiceUpdate).toHaveBeenCalledWith(
@@ -144,7 +157,7 @@ describe('fetch registry metadata', () => {
 
     it('should throw an error if fetched data is not array', async () => {
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue('foo');
+      mockFetchRemoteData.mockResolvedValue('foo');
       mockSessionStorageServiceGet.mockReturnValue(undefined);
 
       let errorMessage: string | undefined;
@@ -157,9 +170,10 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith(
-        'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index',
-      );
+      expect(mockFetchRemoteData.mock.calls).toEqual([
+        ['https://eclipse-che.github.io/che-devfile-registry/7.71.0/index'],
+        ['https://eclipse-che.github.io/che-devfile-registry/7.71.0/devfiles/index.json'],
+      ]);
       expect(mockSessionStorageServiceUpdate).not.toHaveBeenCalled();
       expect(errorMessage).toEqual(
         'Failed to fetch devfiles metadata from registry URL: https://eclipse-che.github.io/che-devfile-registry/7.71.0/, reason: Returned value is not array.',
@@ -179,7 +193,7 @@ describe('fetch registry metadata', () => {
         },
       };
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue([
+      mockFetchRemoteData.mockResolvedValue([
         {
           name: 'java',
           links: {
@@ -196,7 +210,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith(
+      expect(mockFetchRemoteData).toBeCalledWith(
         'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index',
       );
       expect(console.warn).toBeCalledTimes(2);
@@ -224,7 +238,7 @@ describe('fetch registry metadata', () => {
       const time = 1555555555555;
       const elapsedTime = 59 * 60 * 1000;
       mockDateNow.mockReturnValue(time + elapsedTime);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(
         JSON.stringify({
           'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index': {
@@ -239,7 +253,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).not.toBeCalled();
+      expect(mockFetchRemoteData).not.toBeCalled();
       expect(mockSessionStorageServiceUpdate).not.toBeCalled();
       expect(resolved).toEqual([metadata]);
     });
@@ -256,7 +270,7 @@ describe('fetch registry metadata', () => {
       const time = 1555555555555;
       const elapsedTime = 61 * 60 * 1000;
       mockDateNow.mockReturnValue(time + elapsedTime);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(
         JSON.stringify({
           'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index': {
@@ -271,7 +285,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith(
+      expect(mockFetchRemoteData).toBeCalledWith(
         'https://eclipse-che.github.io/che-devfile-registry/7.71.0/index',
       );
       expect(mockSessionStorageServiceUpdate).toHaveBeenCalledWith(
@@ -300,7 +314,7 @@ describe('fetch registry metadata', () => {
         },
       };
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(undefined);
 
       const resolved = await fetchRegistryMetadata(baseUrl, true);
@@ -308,7 +322,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith('https://registry.devfile.io/index');
+      expect(mockFetchRemoteData).toBeCalledWith('https://registry.devfile.io/index');
       expect(mockSessionStorageServiceUpdate).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
         JSON.stringify({
@@ -323,7 +337,7 @@ describe('fetch registry metadata', () => {
 
     it('should throw an error if fetched data is not array', async () => {
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue('foo');
+      mockFetchRemoteData.mockResolvedValue('foo');
       mockSessionStorageServiceGet.mockReturnValue(undefined);
 
       let errorMessage: string | undefined;
@@ -336,7 +350,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith('https://registry.devfile.io/index');
+      expect(mockFetchRemoteData).toBeCalledWith('https://registry.devfile.io/index');
       expect(mockSessionStorageServiceUpdate).not.toHaveBeenCalled();
       expect(errorMessage).toEqual(
         'Failed to fetch devfiles metadata from registry URL: https://registry.devfile.io/, reason: Returned value is not array.',
@@ -356,7 +370,7 @@ describe('fetch registry metadata', () => {
         },
       };
       mockDateNow.mockReturnValue(1555555555555);
-      mockFetchData.mockResolvedValue([
+      mockFetchRemoteData.mockResolvedValue([
         {
           name: 'java',
           links: {
@@ -373,7 +387,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith('https://registry.devfile.io/index');
+      expect(mockFetchRemoteData).toBeCalledWith('https://registry.devfile.io/index');
       expect(console.warn).toBeCalledTimes(2);
       expect(mockSessionStorageServiceUpdate).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
@@ -399,7 +413,7 @@ describe('fetch registry metadata', () => {
       const time = 1555555555555;
       const elapsedTime = 59 * 60 * 1000;
       mockDateNow.mockReturnValue(time + elapsedTime);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(
         JSON.stringify({
           'https://registry.devfile.io/index': {
@@ -414,7 +428,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).not.toBeCalled();
+      expect(mockFetchRemoteData).not.toBeCalled();
       expect(mockSessionStorageServiceUpdate).not.toBeCalled();
       expect(resolved).toEqual([metadata]);
     });
@@ -431,7 +445,7 @@ describe('fetch registry metadata', () => {
       const time = 1555555555555;
       const elapsedTime = 61 * 60 * 1000;
       mockDateNow.mockReturnValue(time + elapsedTime);
-      mockFetchData.mockResolvedValue([metadata]);
+      mockFetchRemoteData.mockResolvedValue([metadata]);
       mockSessionStorageServiceGet.mockReturnValue(
         JSON.stringify({
           'https://registry.devfile.io/index': {
@@ -446,7 +460,7 @@ describe('fetch registry metadata', () => {
       expect(mockSessionStorageServiceGet).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
       );
-      expect(mockFetchData).toBeCalledWith('https://registry.devfile.io/index');
+      expect(mockFetchRemoteData).toBeCalledWith('https://registry.devfile.io/index');
       expect(mockSessionStorageServiceUpdate).toHaveBeenCalledWith(
         SessionStorageKey.EXTERNAL_REGISTRIES,
         JSON.stringify({
