@@ -14,7 +14,7 @@ import {
   V1alpha2DevWorkspaceSpecTemplateComponents,
   V1alpha2DevWorkspaceTemplateSpec,
   V1alpha2DevWorkspaceTemplateSpecComponents,
-  V221DevfileComponentsItemsContainer,
+  V222DevfileComponentsItemsContainer,
 } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import { inject, injectable } from 'inversify';
@@ -60,7 +60,7 @@ export const DEVWORKSPACE_DEVFILE = 'che.eclipse.org/devfile';
 
 export const DEVWORKSPACE_METADATA_ANNOTATION = 'dw.metadata.annotations';
 
-export interface ICheEditorOverrideContainer extends V221DevfileComponentsItemsContainer {
+export interface ICheEditorOverrideContainer extends V222DevfileComponentsItemsContainer {
   name: string;
 }
 export interface ICheEditorYaml {
@@ -208,22 +208,7 @@ export class DevWorkspaceClient {
 
   async updateDevWorkspace(
     devWorkspace: devfileApi.DevWorkspace,
-    pluginRegistryUrl: string | undefined,
-    pluginRegistryInternalUrl: string | undefined,
-    openVSXUrl: string | undefined,
-    clusterConsole?: {
-      url: string;
-      title: string;
-    },
   ): Promise<{ headers: DwApi.Headers; devWorkspace: devfileApi.DevWorkspace }> {
-    this.addEnvVarsToContainers(
-      devWorkspace.spec.template.components,
-      pluginRegistryUrl,
-      pluginRegistryInternalUrl,
-      openVSXUrl,
-      clusterConsole,
-    );
-
     return await DwApi.patchWorkspace(devWorkspace.metadata.namespace, devWorkspace.metadata.name, [
       {
         op: 'replace',
@@ -463,11 +448,7 @@ export class DevWorkspaceClient {
         DEVWORKSPACE_CONFIG_ATTR,
       )}`;
       if (attributes) {
-        if (attributes[DEVWORKSPACE_CONFIG_ATTR]) {
-          if (attributes[DEVWORKSPACE_CONFIG_ATTR] !== devworkspaceConfig) {
-            patch.push({ op: 'replace', path: devworkspaceConfigPath, value: devworkspaceConfig });
-          }
-        } else {
+        if (!attributes[DEVWORKSPACE_CONFIG_ATTR]) {
           patch.push({ op: 'add', path: devworkspaceConfigPath, value: devworkspaceConfig });
         }
       } else {
