@@ -11,7 +11,6 @@
  */
 
 import common from '@eclipse-che/common';
-import { includesAxiosResponse } from '@eclipse-che/common/lib/helpers/errors';
 import { dump, load } from 'js-yaml';
 import { ThunkDispatch } from 'redux-thunk';
 
@@ -50,7 +49,7 @@ export function getErrorMessage(error: unknown): string {
  * Checks for login page in the axios response data
  */
 export function hasLoginPage(error: unknown): boolean {
-  if (includesAxiosResponse(error)) {
+  if (common.helpers.errors.includesAxiosResponse(error)) {
     const response = error.response;
     if (typeof response.data === 'string') {
       try {
@@ -129,7 +128,7 @@ export async function getCustomEditor(
   dispatch: ThunkDispatch<AppState, unknown, KnownAction>,
   getState: () => AppState,
 ): Promise<string | undefined> {
-  let editorsDevfile: devfileApi.Devfile | undefined = undefined;
+  let editorsDevfile: devfileApi.Devfile | undefined;
 
   // do we have a custom editor specified in the repository ?
   const cheEditorYaml = optionalFilesContent[CHE_EDITOR_YAML_PATH]
@@ -140,8 +139,8 @@ export async function getCustomEditor(
     // check the content of cheEditor file
     console.debug('Using the repository .che/che-editor.yaml file', cheEditorYaml);
 
-    let repositoryEditorYaml: devfileApi.Devfile | undefined = undefined;
-    let repositoryEditorYamlUrl: string | undefined = undefined;
+    let repositoryEditorYaml: devfileApi.Devfile | undefined;
+    let repositoryEditorYamlUrl: string | undefined;
     // it's an inlined editor, use the inline content
     if (cheEditorYaml.inline) {
       console.debug('Using the inline content of the repository editor');
