@@ -11,13 +11,16 @@
  */
 
 import mockAxios from 'axios';
+import { AnyAction } from 'redux';
 import { MockStoreEnhanced } from 'redux-mock-store';
 import { ThunkDispatch } from 'redux-thunk';
-import { FakeStoreBuilder } from '../../__mocks__/storeBuilder';
+
+import { AppState } from '@/store';
+import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+import { AUTHORIZED } from '@/store/sanityCheckMiddleware';
+
 import * as dwDockerConfigStore from '..';
-import { AppState } from '../..';
-import { AnyAction } from 'redux';
-import { AUTHORIZED } from '../../sanityCheckMiddleware';
+import { Type } from '..';
 
 // mute the outputs
 console.error = jest.fn();
@@ -48,11 +51,11 @@ describe('dwDockerConfig store', () => {
 
       const expectedActions: dwDockerConfigStore.KnownAction[] = [
         {
-          type: 'REQUEST_DEVWORKSPACE_CREDENTIALS',
+          type: Type.REQUEST_DEVWORKSPACE_CREDENTIALS,
           check: AUTHORIZED,
         },
         {
-          type: 'SET_DEVWORKSPACE_CREDENTIALS',
+          type: Type.SET_DEVWORKSPACE_CREDENTIALS,
           registries: [
             {
               password: 'XXXXXXXXXXXXXXX',
@@ -93,11 +96,11 @@ describe('dwDockerConfig store', () => {
 
       const expectedActions: dwDockerConfigStore.KnownAction[] = [
         {
-          type: 'REQUEST_DEVWORKSPACE_CREDENTIALS',
+          type: Type.REQUEST_DEVWORKSPACE_CREDENTIALS,
           check: AUTHORIZED,
         },
         {
-          type: 'SET_DEVWORKSPACE_CREDENTIALS',
+          type: Type.SET_DEVWORKSPACE_CREDENTIALS,
           registries: [
             {
               password: 'YYYYYYYYYYYY',
@@ -115,7 +118,7 @@ describe('dwDockerConfig store', () => {
     describe('reducers', () => {
       it('should return initial state', () => {
         const incomingAction: dwDockerConfigStore.RequestCredentialsAction = {
-          type: 'REQUEST_DEVWORKSPACE_CREDENTIALS',
+          type: Type.REQUEST_DEVWORKSPACE_CREDENTIALS,
           check: AUTHORIZED,
         };
         const initialState = dwDockerConfigStore.reducer(undefined, incomingAction);
@@ -180,7 +183,7 @@ describe('dwDockerConfig store', () => {
           error: undefined,
         };
         const incomingAction: dwDockerConfigStore.RequestCredentialsAction = {
-          type: 'REQUEST_DEVWORKSPACE_CREDENTIALS',
+          type: Type.REQUEST_DEVWORKSPACE_CREDENTIALS,
           check: AUTHORIZED,
         };
 
@@ -216,7 +219,7 @@ describe('dwDockerConfig store', () => {
           error: undefined,
         };
         const incomingAction: dwDockerConfigStore.SetCredentialsAction = {
-          type: 'SET_DEVWORKSPACE_CREDENTIALS',
+          type: Type.SET_DEVWORKSPACE_CREDENTIALS,
           registries: [],
           resourceVersion: '345',
         };
@@ -241,7 +244,7 @@ describe('dwDockerConfig store', () => {
           error: undefined,
         };
         const incomingAction: dwDockerConfigStore.ReceiveErrorAction = {
-          type: 'RECEIVE_DEVWORKSPACE_CREDENTIALS_ERROR',
+          type: Type.RECEIVE_DEVWORKSPACE_CREDENTIALS_ERROR,
           error: 'unexpected error',
         };
 
