@@ -11,8 +11,10 @@
  */
 
 import { createSelector } from 'reselect';
+
+import { State } from '@/store/DockerConfig/index';
+
 import { AppState } from '..';
-import { State } from './dockerConfigState';
 
 const selectState = (state: AppState) => state.dockerConfig;
 
