@@ -76,6 +76,9 @@ export class FakeStoreBuilder {
           runTimeout: -1,
           startTimeout: 300,
         },
+        defaultNamespace: {
+          autoProvision: true,
+        },
         cheNamespace: '',
         devfileRegistry: {
           disableInternalRegistry: false,
@@ -126,6 +129,8 @@ export class FakeStoreBuilder {
     gitOauthConfig: {
       isLoading: false,
       gitOauth: [],
+      providersWithToken: [],
+      skipOauthProviders: [],
       error: undefined,
     },
     devfileRegistries: {
@@ -198,12 +203,16 @@ export class FakeStoreBuilder {
 
   public withGitOauthConfig(
     gitOauth: IGitOauth[],
+    providersWithToken: api.GitOauthProvider[],
+    skipOauthProviders: api.GitOauthProvider[],
     isLoading = false,
     error?: string,
   ): FakeStoreBuilder {
     this.state.gitOauthConfig.gitOauth = gitOauth;
-    this.state.dockerConfig.isLoading = isLoading;
-    this.state.dockerConfig.error = error;
+    this.state.gitOauthConfig.providersWithToken = providersWithToken;
+    this.state.gitOauthConfig.skipOauthProviders = skipOauthProviders;
+    this.state.gitOauthConfig.isLoading = isLoading;
+    this.state.gitOauthConfig.error = error;
     return this;
   }
 
